@@ -104,19 +104,19 @@ get_consumer_secret (GoaOAuthProvider *provider)
 static const gchar *
 get_request_uri (GoaOAuthProvider *provider)
 {
-  return "http://m.flickr.com/services/oauth/request_token";
+  return "https://m.flickr.com/services/oauth/request_token";
 }
 
 static const gchar *
 get_authorization_uri (GoaOAuthProvider *provider)
 {
-  return "http://m.flickr.com/services/oauth/authorize";
+  return "https://m.flickr.com/services/oauth/authorize";
 }
 
 static const gchar *
 get_token_uri (GoaOAuthProvider *provider)
 {
-  return "http://m.flickr.com/services/oauth/access_token";
+  return "https://m.flickr.com/services/oauth/access_token";
 }
 
 static const gchar *
@@ -165,7 +165,7 @@ get_identity_sync (GoaOAuthProvider  *provider,
                                       goa_oauth_provider_get_consumer_secret (provider),
                                       access_token,
                                       access_token_secret,
-                                      "http://api.flickr.com/services/rest",
+                                      "https://api.flickr.com/services/rest",
                                       FALSE);
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_add_param (call, "method", "flickr.test.login");
@@ -393,14 +393,6 @@ build_object (GoaProvider         *provider,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static gboolean
-get_use_external_browser (GoaOAuthProvider *provider)
-{
-  return FALSE;
-}
-
-/* ---------------------------------------------------------------------------------------------------- */
-
 static void
 show_account (GoaProvider         *provider,
               GoaClient           *client,
@@ -464,7 +456,6 @@ goa_flickr_provider_class_init (GoaFlickrProviderClass *klass)
   oauth_class->get_token_uri            = get_token_uri;
   oauth_class->get_callback_uri         = get_callback_uri;
   oauth_class->get_authentication_cookie = get_authentication_cookie;
-  oauth_class->get_use_external_browser = get_use_external_browser;
   oauth_class->parse_request_token_error = parse_request_token_error;
   oauth_class->add_account_key_values    = add_account_key_values;
 }
