@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012 Red Hat, Inc.
+ * Copyright (C) 2011, 2012, 2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -85,40 +85,6 @@ is_authorization_error (GError *error)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static gboolean
-goa_oauth_provider_get_use_external_browser_default (GoaOAuthProvider  *provider)
-{
-  return FALSE;
-}
-
-/**
- * goa_oauth_provider_get_use_external_browser:
- * @provider: A #GoaOAuthProvider.
- *
- * Returns whether an external browser (the users default browser)
- * should be used for user interaction.
- *
- * If an external browser is used, then the dialogs presented in
- * goa_provider_add_account() and
- * goa_provider_refresh_account() will show a simple "Paste
- * authorization code here" instructions along with an entry and
- * button.
- *
- * This is a virtual method where the default implementation returns
- * %FALSE.
- *
- * Returns: %TRUE if the user interaction should happen in an external
- * browser, %FALSE to use an embedded browser widget.
- */
-gboolean
-goa_oauth_provider_get_use_external_browser (GoaOAuthProvider *provider)
-{
-  g_return_val_if_fail (GOA_IS_OAUTH_PROVIDER (provider), FALSE);
-  return GOA_OAUTH_PROVIDER_GET_CLASS (provider)->get_use_external_browser (provider);
-}
-
-/* ---------------------------------------------------------------------------------------------------- */
-
 static gboolean
 goa_oauth_provider_get_use_mobile_browser_default (GoaOAuthProvider  *provider)
 {
@@ -663,33 +629,6 @@ typedef struct
   gint session_handle_expires_in;
 } IdentifyData;
 
-static void
-check_cookie (SoupCookie *cookie, gpointer user_data)
-{
-  IdentifyData *data = user_data;
-  GList *children;
-  GList *l;
-  GoaOAuthProvider *provider = data->provider;
-  GtkDialog *dialog = data->dialog;
-  GtkWidget *action_area;
-  const gchar *auth_cookie;
-  const gchar *name;
-
-  auth_cookie = goa_oauth_provider_get_authentication_cookie (provider);
-  name = soup_cookie_get_name (cookie);
-  if (g_strcmp0 (auth_cookie, name) != 0)
-    return;
-
-  action_area = gtk_dialog_get_action_area (dialog);
-  children = gtk_container_get_children (GTK_CONTAINER (action_area));
-  for (l = children; l != NULL; l = l->next)
-    {
-      GtkWidget *child = l->data;
-      gtk_container_remove (GTK_CONTAINER (action_area), child);
-    }
-  g_list_free (children);
-}
-
 static void
 on_dom_node_click (WebKitDOMNode *element, WebKitDOMEvent *event, gpointer user_data)
 {
@@ -713,21 +652,12 @@ static void
 on_web_view_document_load_finished (WebKitWebView *web_view, WebKitWebFrame *frame, gpointer user_data)
 {
   IdentifyData *data = user_data;
-  GSList *slist;
   GoaOAuthProvider *provider = data->provider;
-  SoupCookieJar *cookie_jar;
-  SoupSession *session;
   WebKitDOMDocument *document;
   WebKitDOMNodeList *elements;
   gulong element_count;
   gulong i;
 
-  session = webkit_get_default_session ();
-  cookie_jar = SOUP_COOKIE_JAR (soup_session_get_feature (session, SOUP_TYPE_COOKIE_JAR));
-  slist = soup_cookie_jar_all_cookies (cookie_jar);
-  g_slist_foreach (slist, (GFunc) check_cookie, data);
-  g_slist_free_full (slist, (GDestroyNotify) soup_cookie_free);
-
   document = webkit_web_view_get_dom_document (WEBKIT_WEB_VIEW (web_view));
   elements = webkit_dom_document_get_elements_by_tag_name (document, "*");
   element_count = webkit_dom_node_list_get_length (elements);
@@ -814,19 +744,6 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
     }
 }
 
-static void
-on_entry_changed (GtkEditable *editable,
-                  gpointer     user_data)
-{
-  IdentifyData *data = user_data;
-  gboolean sensitive;
-
-  g_free (data->oauth_verifier);
-  data->oauth_verifier = g_strdup (gtk_entry_get_text (GTK_ENTRY (editable)));
-  sensitive = data->oauth_verifier != NULL && (strlen (data->oauth_verifier) > 0);
-  gtk_dialog_set_response_sensitive (data->dialog, GTK_RESPONSE_OK, sensitive);
-}
-
 static void
 rest_proxy_call_cb (RestProxyCall *call, const GError *error, GObject *weak_object, gpointer user_data)
 {
@@ -857,9 +774,10 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
   RestProxy *proxy;
   RestProxyCall *call;
   GHashTable *f;
+  GtkWidget *embed;
   GtkWidget *grid;
   GtkWidget *spinner;
-  gboolean use_external_browser;
+  GtkWidget *web_view;
   gchar **request_params;
   guint n;
 
@@ -877,8 +795,6 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
   url = NULL;
   request_params = NULL;
 
-  use_external_browser = goa_oauth_provider_get_use_external_browser (provider);
-
   /* TODO: check with NM whether we're online, if not - return error */
 
   memset (&data, '\0', sizeof (IdentifyData));
@@ -892,10 +808,7 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
                            goa_oauth_provider_get_request_uri (provider), FALSE);
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_set_method (call, "POST");
-  if (use_external_browser)
-    rest_proxy_call_add_param (call, "oauth_callback", "oob");
-  else
-    rest_proxy_call_add_param (call, "oauth_callback", goa_oauth_provider_get_callback_uri (provider));
+  rest_proxy_call_add_param (call, "oauth_callback", goa_oauth_provider_get_callback_uri (provider));
 
   request_params = goa_oauth_provider_get_request_uri_params (provider);
   if (request_params != NULL)
@@ -964,67 +877,23 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
   url = goa_oauth_provider_build_authorization_uri (provider,
                                                             goa_oauth_provider_get_authorization_uri (provider),
                                                             escaped_request_token);
-  if (use_external_browser)
-    {
-      GtkWidget *label;
-      GtkWidget *entry;
-      gchar *escaped_url;
-      gchar *markup;
 
-      escaped_url = g_markup_escape_text (url, -1);
-      /* Translators: The verb "Paste" is used when asking the user to paste a string from a web browser window */
-      markup = g_strdup_printf (_("Paste token obtained from the <a href=\"%s\">authorization page</a>:"),
-                                escaped_url);
-      g_free (escaped_url);
+  web_view = goa_web_view_new ();
+  gtk_widget_set_hexpand (web_view, TRUE);
+  gtk_widget_set_vexpand (web_view, TRUE);
+  embed = goa_web_view_get_view (GOA_WEB_VIEW (web_view));
 
-      label = gtk_label_new (NULL);
-      gtk_label_set_markup (GTK_LABEL (label), markup);
-      g_free (markup);
-      gtk_container_add (GTK_CONTAINER (grid), label);
-      entry = gtk_entry_new ();
-      gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
-      gtk_container_add (GTK_CONTAINER (grid), entry);
-      gtk_widget_grab_focus (entry);
-      gtk_widget_show_all (GTK_WIDGET (vbox));
+  if (goa_oauth_provider_get_use_mobile_browser (provider))
+    goa_web_view_fake_mobile (GOA_WEB_VIEW (web_view));
 
-      gtk_dialog_add_button (dialog, _("_OK"), GTK_RESPONSE_OK);
-      gtk_dialog_set_default_response (dialog, GTK_RESPONSE_OK);
-      gtk_dialog_set_response_sensitive (dialog, GTK_RESPONSE_OK, FALSE);
-      g_signal_connect (entry, "changed", G_CALLBACK (on_entry_changed), &data);
+  webkit_web_view_load_uri (WEBKIT_WEB_VIEW (embed), url);
+  g_signal_connect (embed, "document-load-finished", G_CALLBACK (on_web_view_document_load_finished), &data);
+  g_signal_connect (embed,
+                    "navigation-policy-decision-requested",
+                    G_CALLBACK (on_web_view_navigation_policy_decision_requested),
+                    &data);
 
-      if (!gtk_show_uri (NULL,
-                         url,
-                         GDK_CURRENT_TIME,
-                         &data.error))
-        {
-          goto out;
-        }
-    }
-  else
-    {
-      GtkWidget *web_view;
-      GtkWidget *embed;
-
-      web_view = goa_web_view_new ();
-      gtk_widget_set_hexpand (web_view, TRUE);
-      gtk_widget_set_vexpand (web_view, TRUE);
-      embed = goa_web_view_get_view (GOA_WEB_VIEW (web_view));
-
-      if (goa_oauth_provider_get_use_mobile_browser (provider))
-        goa_web_view_fake_mobile (GOA_WEB_VIEW (web_view));
-
-      webkit_web_view_load_uri (WEBKIT_WEB_VIEW (embed), url);
-      g_signal_connect (embed,
-                        "document-load-finished",
-                        G_CALLBACK (on_web_view_document_load_finished),
-                        &data);
-      g_signal_connect (embed,
-                        "navigation-policy-decision-requested",
-                        G_CALLBACK (on_web_view_navigation_policy_decision_requested),
-                        &data);
-
-      gtk_container_add (GTK_CONTAINER (grid), web_view);
-    }
+  gtk_container_add (GTK_CONTAINER (grid), web_view);
 
   gtk_widget_show_all (GTK_WIDGET (vbox));
   gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1346,8 +1215,10 @@ goa_oauth_provider_refresh_account (GoaProvider  *_provider,
 
   dialog = gtk_dialog_new_with_buttons (NULL,
                                         parent,
-                                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                        _("_Cancel"), GTK_RESPONSE_REJECT,
+                                        GTK_DIALOG_MODAL
+                                        | GTK_DIALOG_DESTROY_WITH_PARENT
+                                        | GTK_DIALOG_USE_HEADER_BAR,
+                                        NULL,
                                         NULL);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 12);
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -1814,7 +1685,6 @@ goa_oauth_provider_class_init (GoaOAuthProviderClass *klass)
   provider_class->ensure_credentials_sync    = goa_oauth_provider_ensure_credentials_sync;
 
   klass->build_authorization_uri  = goa_oauth_provider_build_authorization_uri_default;
-  klass->get_use_external_browser = goa_oauth_provider_get_use_external_browser_default;
   klass->get_use_mobile_browser   = goa_oauth_provider_get_use_mobile_browser_default;
   klass->is_password_node         = goa_oauth_provider_is_password_node_default;
   klass->get_request_uri_params   = goa_oauth_provider_get_request_uri_params_default;
